==> nextcloud-23.0.9.tgz: nextcloud/apps/viewer/l10n/sr.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Прегледач",
    "Simple file viewer with slideshow for media" : "Једноставни прегледач фајлова са слајд-шоу подршком за медијске фајлове",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Прикажите најновије слике са одмора и видео записе као у филмовима. Прикажите делић вашег најновијег романа директно из Некстклауда. Одаберите најбољи ГИФ из колекције, захваљујући директном прегледу омиљених фајлова и још много тога!",
    "Your browser does not support audio." : "Ваш веб читач не подржава аудио.",
    "Error loading {name}" : "Грешка при учитавању {name}",
    "Unsaved changes" : "Несачуване измене",
    "Your browser does not support videos." : "Ваш веб читач не подржава видео записе.",
    "Edit" : "Измени",
    "Open sidebar" : "Отвори бочну траку",
    "Download" : "Преузми",
    "Delete" : "Избриши",
    "There is no plugin available to display this file type" : "Нема додатка којим може да се прикаже овај тип фајла",
    "View" : "Погледај",
    "Name" : "Име",
    "Save" : "Сачувај",
    "Back" : "Назад",
    "Loading …" : "Учитавање…",
    "Reset" : "Ресетуј",
    "Cancel" : "Поништи",
    "Continue" : "Настави",
    "Undo" : "Опозови",
    "Redo" : "Понови",
    "Zoom in" : "Увеличај",
    "Original" : "Оригинал",
    "Custom" : "Прилагођено",
    "Value" : "Вредност",
    "Image" : "Слика",
    "Text" : "Текст",
    "Size" : "величина",
    "Position" : "Позиција",
    "Extension" : "Екстензија"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-24.0.10.tgz: nextcloud/apps/viewer/l10n/sr.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Прегледач",
    "Simple file viewer with slideshow for media" : "Једноставни прегледач фајлова са слајд-шоу подршком за медијске фајлове",
    "Your browser does not support audio." : "Ваш веб читач не подржава аудио.",
    "Error loading {name}" : "Грешка при учитавању {name}",
    "Image saved" : "Слика сачувана.",
    "Unsaved changes" : "Несачуване измене",
    "Your browser does not support videos." : "Ваш веб читач не подржава видео записе.",
    "Edit" : "Измени",
    "Open sidebar" : "Отвори бочну траку",
    "Download" : "Преузми",
    "Delete" : "Избриши",
    "There is no plugin available to display this file type" : "Нема додатка којим може да се прикаже овај тип фајла",
    "View" : "Погледај",
    "Name" : "Име",
    "Save" : "Сачувај",
    "Back" : "Назад",
    "Loading …" : "Учитавање…",
    "Reset" : "Ресетуј",
    "Cancel" : "Поништи",
    "Continue" : "Настави",
    "Undo" : "Опозови",
    "Redo" : "Понови",
    "Zoom in" : "Увеличај",
    "Original" : "Оригинал",
    "Custom" : "Прилагођено",
    "Value" : "Вредност",
    "Image" : "Слика",
    "Line" : "Линија",
    "Text" : "Текст",
    "Size" : "величина",
    "Position" : "Позиција",
    "Extension" : "Екстензија",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Прикажите најновије слике са одмора и видео записе као у филмовима. Прикажите делић вашег најновијег романа директно из Некстклауда. Одаберите најбољи ГИФ из колекције, захваљујући директном прегледу омиљених фајлова и још много тога!"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
